@@ -112,11 +112,13 @@ p.add_argument('-s', action='store_true', default=None, help="don't capture outp
 p.add_argument('--tb', action='store', default="native", help='traceback print mode (long/short/line/native/no)')
 p.add_argument('-p', action='append', default=[], help="early-load given plugin (multi-allowed)")
 p.add_argument('-m', action='append', default=[], help="filter based on marks")
+p.add_argument('-n', action='store', default=None, help="number of processes to fork")
 p.add_argument('--traceconfig', action='store_true', default=None, help="trace considerations of conftest.py files")
 p.add_argument('--pdb', action='store_true', default=None, help="start the interactive Python debugger on errors")
 p.add_argument('--maxfail', action='store', default=None, help="exit after first num failures or errors.")
 p.add_argument('--collectonly', action='store_true', default=None, help="only collect tests, don't execute them")
 p.add_argument('--durations', action='store', default=None, help='show N slowest setup/test durations (N=0 for all)')
+p.add_argument('--debug', action='store', default=None, help="store internal tracing debug information in 'pytestdebug.log'.")
 p.add_argument('--version', action='version', version='Py.Saunter %s' % saunter.__version__)
 
 results = p.parse_args()
@@ -144,7 +146,7 @@ for noneable in ['v', 's']:
     if noneable in results.__dict__ and results.__dict__[noneable] != None:
         arguments.append("-%s" % noneable)
 
-for noneable in ['traceconfig', 'pdb', 'collectonly']:
+for noneable in ['traceconfig', 'pdb', 'collectonly', "debug"]:
     if noneable in results.__dict__ and results.__dict__[noneable] != None:
         arguments.append("--%s" % noneable)
 
@@ -153,6 +155,10 @@ for has_value in ['maxfail', 'durations']:
         arguments.append("--%s=%s" % (has_value, results.__dict__[has_value][0]))
         # arguments.append(results.__dict__[has_value][0])        
 
+if 'n' in results.__dict__ and results.__dict__['n'] != None:
+    arguments.append("--dist=load")
+    arguments.append("--tx=%s*popen" % results.__dict__['n'])
+
 # plugin control
 if len(results.p) == 1:
     arguments.append("-p")
@@ -162,9 +168,6 @@ else:
         arguments.append("-p")
         arguments.append(p)
 
-# pythonpath
-sys.path.append(os.path.join(cwd, "modules"))
-
 import saunter.SeleniumServer
 
 import saunter.ConfigWrapper
